A function that combines useful information summarizing model fit.
as.evoTS.multi.BW.acceldecel.fit(
converge,
modelName,
logL,
ancestral.values,
SE.anc,
r,
SE.r,
R,
SE.R,
method,
K,
n,
iter
)info on model convergence
description of the model.
log-likelihood of model
maximum-likelihood estimates of the ancestral trait values
standard errors of the estimated ancestral states
maximum-likelihood estimates of the r parameter
standard error of the r parameter
maximum-likelihood estimates of the parameters in the R matrix
standard errors of the parameters in the R matrix
the parameterization used: Joint
number of parameters in the model
sample size
the number of times the optimization method is run from different starting points. Default is NULL, meaning the optimization is run once.
Kjetil Lysne Voje
This function is used by the model-fitting routines for the Unbiased Random Walk models with an accelerated and decelerated rate of evoluton to create standardized output