Learn R Programming

evoTS (version 1.0.3)

as.evoTSfit.OUBM: Class for fit to evolutionary sequence (time-series) models

Description

A function that combines useful information summarizing model fit.

Usage

as.evoTSfit.OUBM(logL, parameters, modelName, method, K, n, se)

Arguments

logL

log-likelihood of model

parameters

maximum-likelihood estimates of the parameters

modelName

description of the model

method

the parameterization used: Joint

K

number of parameters in the model

n

sample size

se

standard errors of parameter estimates

Author

Kjetil Lysne Voje

Details

This function is used by the model-fitting routines for the univariate Ornstein-Uhlenbeck model where the optimum evolves as an Unbiased Random Walk to create standardized output