fit.all.univariate: Fit all univariate models to an evolutionary sequence (time-series).
Description
Wrapper function to find maximum likelihood solutions for all univariate models (excluding models with mode shifts) to an evolutionary sequence (time-series).
Usage
fit.all.univariate(y, pool = TRUE)
Value
The function returns a list of all investigated models and their highest log-likelihood (and their corresponding AICc and AICc weight).
Arguments
y
an univariate paleoTS object.
pool
indicating whether to pool variances across samples
Author
Kjetil Lysne Voje
References
Hunt, G. 2006. Fitting and comparing models of phyletic evolution: random walks and beyond. Paleobiology 32:578–601
Hunt, G., Bell, M. A. & Travis, M. P. Evolution towards a new adaptive optimum: Phenotypic evolution in a fossil stickleback lineage. Evolution 62:700–710 (2008)