Returns log-likelihood for a model with an Unbiased Random Walk in the first segment and an Unbiased Random Walk in the second segment.
logL.joint.URW.URW(p, y, gg)The log-likelihood of the parameter estimates, given the data.
parameters of the model to be optimized
a paleoTS object
numeric vector indicating membership of each sample in a segment
Kjetil Lysne Voje
In general, users will not access these functions directly, but instead use the optimization functions, which use these functions to find the best-supported parameter values.