Learn R Programming

evoTS (version 1.0.3)

opt.joint.URW.Stasis: Optimization and log-likelihoods for pairs of models.

Description

A collections of functions that serves the function fit.mode.shift. See fit.mode.shift for info.

Usage

opt.joint.URW.Stasis(
  y,
  gg,
  cl = list(fnscale = -1),
  pool = TRUE,
  meth = "L-BFGS-B",
  hess = FALSE
)

Arguments

y

a paleoTS object.

gg

numeric vector indicating membership of each sample in segments

cl

control list to be passed to optim

pool

logical indicating whether to pool variances across samples

meth

optimization method, passed to function optim. Default is "L-BFGS-B".

hess

logical, indicating whether to calculate standard errors from the Hessian matrix.

Author

Kjetil Lysne Voje

Details

In general, users will not be access these functions directly, but instead use the wrapper function, which use these functions to find the best-supported parameter values.