A function that combines useful information summarizing model fit.
as.evoTSfit.OUBM(logL, parameters, modelName, method, K, n, se)log-likelihood of model
maximum-likelihood estimates of the parameters
description of the model
the parameterization used: Joint
number of parameters in the model
sample size
standard errors of parameter estimates
Kjetil Lysne Voje
This function is used by the model-fitting routines for the univariate Ornstein-Uhlenbeck model where the optimum evolves as an Unbiased Random Walk to create standardized output