Returns log-likelihood for an Ornstein-Uhlenbeck model where the optimum evolves as a Unbiased Random Walk. The movement of the optimum is not parameterized based on separate data.
logL.joint.OU.BM(p, y, opt.anc)The log-likelihood of the parameter estimates, given the data.
parameters of the model to be optimized
a paleoTS object
logical, indicating if the ancestral trait value is at the optimum (TRUE) or displaced from the optimum (FALSE)
Kjetil Lysne Voje
In general, users will not be access these functions directly, but instead use the optimization functions, which use these functions to find the best-supported parameter values.
Hansen, T. F., Pienaar, J. & Orzack, S. H. A Comparative Method for Studying Adaptation to a Randomly Evolving Environment. Evolution 62, 1965–1977 (2008).