A collections of functions that serves the function fit.mode.shift. See fit.mode.shift for info.
opt.joint.URW.Stasis(
y,
gg,
cl = list(fnscale = -1),
pool = TRUE,
meth = "L-BFGS-B",
hess = FALSE
)a paleoTS object.
numeric vector indicating membership of each sample in segments
control list to be passed to optim
logical indicating whether to pool variances across samples
optimization method, passed to function optim. Default is "L-BFGS-B".
logical, indicating whether to calculate standard errors from the Hessian matrix.
Kjetil Lysne Voje
In general, users will not be access these functions directly, but instead use the wrapper function, which use these functions to find the best-supported parameter values.